pub struct TimeArithmetic { /* private fields */ }time only.Expand description
Options for Time::checked_add and Time::checked_sub.
This type provides a way to ergonomically add one of a few different
duration types to a Time.
The main way to construct values of this type is with its From trait
implementations:
From<Span> for TimeArithmeticadds (or subtracts) the given span to the receiver time.From<SignedDuration> for TimeArithmeticadds (or subtracts) the given signed duration to the receiver time.From<std::time::Duration> for TimeArithmeticadds (or subtracts) the given unsigned duration to the receiver time.
Example
use std::time::Duration;
use jiff::{civil::time, SignedDuration, ToSpan};
let t = time(0, 0, 0, 0);
assert_eq!(t.checked_add(2.hours())?, time(2, 0, 0, 0));
assert_eq!(t.checked_add(SignedDuration::from_hours(2))?, time(2, 0, 0, 0));
assert_eq!(t.checked_add(Duration::from_secs(2 * 60 * 60))?, time(2, 0, 0, 0));