SpanCompare

Struct SpanCompare 

pub struct SpanCompare<'a> { /* private fields */ }
Available on crate feature time only.
Options for Span::compare.

This type provides a way to ergonomically compare two spans with an optional relative datetime. Namely, a relative datetime is only needed when at least one of the two spans being compared has a non-zero calendar unit (years, months, weeks or days). Otherwise, an error will be returned.

Callers may use SpanCompare::days_are_24_hours to opt into 24-hour invariant days (and 7-day weeks) without providing a relative datetime.

The main way to construct values of this type is with its From trait implementations:

  • From<Span> for SpanCompare compares the given span to the receiver in Span::compare.
  • From<(Span, civil::Date)> for SpanCompare compares the given span to the receiver in Span::compare, relative to the given date. There are also From implementations for civil::DateTime, Zoned and SpanRelativeTo.

Example

use jiff::ToSpan;

let span1 = 3.hours();
let span2 = 180.minutes();
assert_eq!(span1.compare(span2)?, std::cmp::Ordering::Equal);

Implementations

Source

impl<'a> SpanCompare<'a>

pub fn days_are_24_hours(self) -> SpanCompare<'a>

This is a convenience function for setting the relative option on this configuration to SpanRelativeTo::days_are_24_hours.

Example

When comparing spans involving days, either a relative datetime must be provided, or a special assertion opting into 24-hour days is required. Otherwise, you get an error.

use jiff::{SpanCompare, ToSpan, Unit};

let span1 = 2.days().hours(12);
let span2 = 60.hours();
// No relative date provided, which results in an error.
assert_eq!(
    span1.compare(span2).unwrap_err().to_string(),
    "using unit 'day' in a span or configuration requires that \
     either a relative reference time be given or \
     `SpanRelativeTo::days_are_24_hours()` is used to indicate \
     invariant 24-hour days, but neither were provided",
);
let ordering = span1.compare(
    SpanCompare::from(span2).days_are_24_hours(),
)?;
assert_eq!(ordering, std::cmp::Ordering::Equal);